==> wapsms-1.0.tar.gz: wapsms/sendsms.c <==
/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version
 * 2 of the License, or (at your option) any later version.
 */

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <unistd.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <netdb.h>
#include <fcntl.h> 
#include <errno.h>
#include <sys/time.h>
#include <ctype.h>

#include "engine.h"

#define KEYSTR "<input type=\"hidden\" value=\""

static char * encode_string(char *buf)
{
	static char m[512];
	char *mp=m;
	
	while(*buf)
	{
		if(*buf==' ')
		{
			*mp++='+';
			buf++;
			continue;
		}
		if(!isalnum(*buf))
		{
			*mp++='%';
			sprintf(mp, "%02X", *buf);
			buf++;
			mp+=2;
			continue;
		}
		*mp++=*buf++;
	}
	*mp=0;
	return m;
}

static void post_message(char *app, int num, char *phone, char *msg)
{
	int s;
	char buf[512];
	char *tp;
	
	if(strlen(msg)>130)
	{
		fprintf(stderr, "%s: message too long.\n", app);
		exit(1);
	}
	
	sprintf(buf, "/uk/cgi-bin/sms/send_uk_sms4.cgi?msgnr=%d&ren=%s&msg=%s&Len=%d&SUBMIT.x=0&SUBMIT.y=0&prg=1",
		num, phone, encode_string(msg), strlen(msg));
		
	s=host_connect("smscgi04-1.lycos.de", 80);
	if(s==-1)
		exit(1);
	host_get_ref(s, "smscgi04-1.lycos.de", buf, "http://www.lycos.co.uk/service/sms/eingabe.html");

	while((tp=host_readline(s))!=NULL)
	{
		if(strstr(tp, "danke"))
			printf("OK - lycos.co.uk delivering SMS.\n");
	}	
	close(s);
}

int main(int argc, char *argv[])
{
	int s;
	char *tp;
	
	if(argc!=3)
	{
		fprintf(stderr, "%s: phone-number message.\n", argv[0]);
		exit(1);
	}
	
	tp=argv[1];
	while(*tp)
	{
		if(!isdigit(*tp))
		{
			fprintf(stderr, "%s: phone number must be numeric.\n",
				argv[0]);
			exit(1);
		}
		tp++;
	}
	if(strncmp(argv[1], "00", 2)==0)
	{
		fprintf(stderr, "%s: only UK numbers supported.\n",
			argv[0]);
		exit(1);
	}
	
	s=host_connect("www.lycos.co.uk", 80);
	if(s==-1)
		exit(1);
	host_get(s, "www.lycos.co.uk", "/service/sms/eingabe.html");
	while((tp=host_readline(s))!=NULL)
	{
		int n;
		if(strncmp(tp, KEYSTR,strlen(KEYSTR)))
			continue;
		if(sscanf(tp+strlen(KEYSTR), "%d", &n)!=1)
			continue;
//		printf("Message ID %d\n", n);
		close(s);
		post_message(argv[0], n, argv[1], argv[2]);
		exit(0);
	}
	fprintf(stderr, "%s: unable to get a message id.\n", argv[0]);
	exit(1);
}

==> wapsms-1.1.tar.gz: wapsms/sendsms.c <==
/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version
 * 2 of the License, or (at your option) any later version.
 */

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <unistd.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <netdb.h>
#include <fcntl.h> 
#include <errno.h>
#include <sys/time.h>
#include <ctype.h>

#include "engine.h"

#define KEYSTR "<input type=\"hidden\" value=\""

static char * encode_string(char *buf)
{
	static char m[512];
	char *mp=m;
	
	while(*buf)
	{
		if(*buf==' ')
		{
			*mp++='+';
			buf++;
			continue;
		}
		if(!isalnum(*buf))
		{
			*mp++='%';
			sprintf(mp, "%02X", *buf);
			buf++;
			mp+=2;
			continue;
		}
		*mp++=*buf++;
	}
	*mp=0;
	return m;
}

static void post_message(char *app, int num, char *phone, char *msg)
{
	int s;
	char buf[512];
	char *tp;
	
	if(strlen(msg)>130)
	{
		fprintf(stderr, "%s: message too long.\n", app);
		exit(1);
	}
	
	sprintf(buf, "/uk/cgi-bin/sms/send_uk_sms5.cgi?msgnr=%d&ren=%s&msg=%s&Len=%d&SUBMIT.x=0&SUBMIT.y=0&prg=1",
		num, phone, encode_string(msg), strlen(msg));
		
	s=host_connect("smscgi01-1.lycos.de", 80);
	if(s==-1)
		exit(1);
	host_get_ref(s, "smscgi01-1.lycos.de", buf, "http://www.lycos.co.uk/service/sms/eingabe.html");

	while((tp=host_readline(s))!=NULL)
	{
		if(strstr(tp, "danke"))
			printf("OK - lycos.co.uk delivering SMS.\n");
	}	
	close(s);
}

int main(int argc, char *argv[])
{
	int s;
	char *tp;
	char *p;
	
	if(argc!=3)
	{
		fprintf(stderr, "%s: phone-number message.\n", argv[0]);
		exit(1);
	}
	
	tp=argv[1];
	while(*tp)
	{
		if(!isdigit(*tp))
		{
			fprintf(stderr, "%s: phone number must be numeric.\n",
				argv[0]);
			exit(1);
		}
		tp++;
	}
	if(strncmp(argv[1], "00", 2)==0)
	{
		fprintf(stderr, "%s: only UK numbers supported.\n",
			argv[0]);
		exit(1);
	}
	
	s=host_connect("www.lycos.co.uk", 80);
	if(s==-1)
		exit(1);
	host_get(s, "www.lycos.co.uk", "/service/sms/eingabe.html");
	while((tp=host_readline(s))!=NULL)
	{
		int n;
		if((p=strstr(tp, KEYSTR))==NULL)
			continue;
		if(sscanf(p+strlen(KEYSTR), "%d", &n)!=1)
			continue;
//		printf("Message ID %d\n", n);
		close(s);
		post_message(argv[0], n, argv[1], argv[2]);
		exit(0);
	}
	fprintf(stderr, "%s: unable to get a message id.\n", argv[0]);
	exit(1);
}
